@@ -3,9 +3,11 @@ import re
 
 import httpx
 from anthropic import AsyncAnthropic
-from anthropic.types.beta import BetaMessage
+from anthropic.types.beta import BetaMessage, BetaBashCodeExecutionToolResultBlock, BetaTextBlock, BetaThinkingBlock, \
+    BetaServerToolUseBlock
 from fastapi import HTTPException
 
+from llm_bridge.client.implementations.claude.claude_response_handler import process_content_block
 from llm_bridge.client.implementations.claude.claude_token_counter import count_claude_output_tokens
 from llm_bridge.client.model_client.claude_client import ClaudeClient
 from llm_bridge.type.chat_response import ChatResponse
@@ -20,16 +22,21 @@ async def process_claude_non_stream_response(
 ) -> ChatResponse:
     text = ""
     thought = ""
+    code = ""
+    code_output = ""
 
-    for content in message.content:
-        if content.type == "thinking":
-            thought += content.thinking
-        if content.type == "text":
-            text += content.text
+    for content_block in message.content:
+        content_block_chat_response = process_content_block(content_block)
+        text += content_block_chat_response.text
+        thought += content_block_chat_response.thought
+        code += content_block_chat_response.code
+        code_output += content_block_chat_response.code_output
 
     chat_response = ChatResponse(
         text=text,
         thought=thought,
+        code=code,
+        code_output=code_output,
     )
     output_tokens = await count_claude_output_tokens(
         client=client,
@@ -39,6 +46,8 @@ async def process_claude_non_stream_response(
     return ChatResponse(
         text=text,
         thought=thought,
+        code=code,
+        code_output=code_output,
         input_tokens=input_tokens,
         output_tokens=output_tokens,
     )
@@ -49,16 +58,27 @@ class NonStreamClaudeClient(ClaudeClient):
         try:
             logging.info(f"messages: {self.messages}")
 
-            message = await self.client.beta.messages.create(
-                model=self.model,
-                max_tokens=self.max_tokens,
-                temperature=self.temperature,
-                system=self.system,
-                messages=serialize(self.messages),
-                thinking=self.thinking,
-                betas=self.betas,
-                tools=self.tools,
-            )
+            if self.thinking:
+                message = await self.client.beta.messages.create(
+                    model=self.model,
+                    max_tokens=self.max_tokens,
+                    temperature=self.temperature,
+                    system=self.system,
+                    messages=serialize(self.messages),
+                    betas=self.betas,
+                    tools=self.tools,
+                    thinking=self.thinking,
+                )
+            else:
+                message = await self.client.beta.messages.create(
+                    model=self.model,
+                    max_tokens=self.max_tokens,
+                    temperature=self.temperature,
+                    system=self.system,
+                    messages=serialize(self.messages),
+                    betas=self.betas,
+                    tools=self.tools,
+                )
 
             return await process_claude_non_stream_response(
                 message=message,
