@@ -8,8 +8,13 @@ async def count_gemini_tokens(
     if usage_metadata is None:
         return 0, 0
     input_tokens = usage_metadata.prompt_token_count
+    if input_tokens is None: # For Vertex AI
+        input_tokens = 0
     output_tokens = usage_metadata.candidates_token_count
     if output_tokens is None:
-        output_tokens = usage_metadata.total_token_count - usage_metadata.prompt_token_count
+        total_token_count = usage_metadata.total_token_count
+        if total_token_count is None: # For Vertex AI
+            total_token_count = 0
+        output_tokens = total_token_count - input_tokens
     return input_tokens, output_tokens
 
