@@ -1,6 +1,6 @@
 import anthropic
 from anthropic.types import ThinkingConfigEnabledParam, AnthropicBetaParam
-from anthropic.types.beta import BetaCodeExecutionTool20250825Param, BetaWebSearchTool20250305Param
+from anthropic.types.beta import BetaWebSearchTool20250305Param, BetaToolUnionParam, BetaCodeExecutionTool20250825Param
 
 from llm_bridge.client.implementations.claude.claude_token_counter import count_claude_input_tokens
 from llm_bridge.client.implementations.claude.non_stream_claude_client import NonStreamClaudeClient
@@ -11,11 +11,13 @@ from llm_bridge.type.message import Message
 
 
 async def create_claude_client(
+        api_key: str,
         messages: list[Message],
         model: str,
         temperature: float,
         stream: bool,
-        api_key: str,
+        thought: bool,
+        code_execution: bool,
 ):
     client = anthropic.AsyncAnthropic(
         api_key=api_key,
@@ -34,24 +36,35 @@ async def create_claude_client(
         messages=claude_messages,
     )
 
-    max_tokens = min(32000, 200000 - input_tokens)
-    thinking = ThinkingConfigEnabledParam(
-        type="enabled",
-        budget_tokens=16000
+    max_tokens = min(
+        32_000,  # Max output: Claude 4.5 64K; Claude 4.1 32K
+        200_000 - input_tokens,  # Context window: Claude Sonnet 4.5 beta: 1M; otherwise 200K
     )
-    temperature = 1
-    betas: list[AnthropicBetaParam] = ["output-128k-2025-02-19", "code-execution-2025-08-25"]
-    tools = [
+    thinking = None
+    if thought:
+        thinking = ThinkingConfigEnabledParam(
+            type="enabled",
+            budget_tokens=max(1024, max_tokens // 2),  # Minimum budget tokens: 1024
+        )
+        temperature = 1
+    betas: list[AnthropicBetaParam] = [
+        "context-1m-2025-08-07",
+        "output-128k-2025-02-19",
+        "code-execution-2025-08-25",
+    ]
+    tools: list[BetaToolUnionParam] = [
         BetaWebSearchTool20250305Param(
             type="web_search_20250305",
             name="web_search",
         ),
-        # Code Execution is unavailable in Claude
-        # BetaCodeExecutionTool20250825Param(
-        #     type="code_execution_20250825",
-        #     name="code_execution",
-        # )
     ]
+    if code_execution:
+        tools.append(
+            BetaCodeExecutionTool20250825Param(
+                type="code_execution_20250825",
+                name="code_execution",
+            )
+        )
 
     if stream:
         return StreamClaudeClient(
@@ -61,10 +74,10 @@ async def create_claude_client(
             system=system,
             client=client,
             max_tokens=max_tokens,
-            thinking=thinking,
             betas=betas,
             input_tokens=input_tokens,
             tools=tools,
+            thinking=thinking,
         )
     else:
         return NonStreamClaudeClient(
@@ -74,10 +87,8 @@ async def create_claude_client(
             system=system,
             client=client,
             max_tokens=max_tokens,
-            thinking=thinking,
             betas=betas,
             input_tokens=input_tokens,
             tools=tools,
+            thinking=thinking,
         )
-
-
